'use strict';

Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const js_1 = tslib_1.__importDefault(require("@eslint/js"));
const typescript_eslint_1 = tslib_1.__importDefault(require("typescript-eslint"));
const eslint_plugin_import_1 = require("eslint-plugin-import");
const eslintrc_1 = require("@eslint/eslintrc");
const eslint_plugin_react_1 = tslib_1.__importDefault(require("eslint-plugin-react"));
const eslint_plugin_jsx_a11y_1 = tslib_1.__importDefault(require("eslint-plugin-jsx-a11y"));
const globals_1 = tslib_1.__importDefault(require("globals"));
const compat = new eslintrc_1.FlatCompat({
    baseDirectory: __dirname,
});
const flatConfig = typescript_eslint_1.default.config(js_1.default.configs.recommended, ...typescript_eslint_1.default.configs.strictTypeChecked, {
    languageOptions: {
        parserOptions: {
            projectService: true, // alternative: `project: ['./tsconfig.json']` for older setups
        },
    },
}, ...compat.extends("eslint-config-airbnb"), eslint_plugin_import_1.flatConfigs.recommended, {
    name: "@launchware/eslint-config-react/react",
    files: ["**/*.{js,jsx,ts,tsx}"],
    plugins: {
        react: eslint_plugin_react_1.default.default ?? eslint_plugin_react_1.default,
        "jsx-a11y": eslint_plugin_jsx_a11y_1.default,
    },
    languageOptions: {
        globals: globals_1.default.browser,
        parserOptions: {
            ecmaFeatures: { jsx: true },
        },
    },
    rules: {
        // General best practices
        "no-shadow": "off",
        "no-use-before-define": "off",
        "no-underscore-dangle": "off",
        // TypeScript-specific
        "@typescript-eslint/no-unused-vars": ["error"],
        // React-specific
        "react/prop-types": "off",
        "react/jsx-filename-extension": ["error", { extensions: [".jsx", ".tsx"] }],
        "react/jsx-props-no-spreading": "off",
        // React Refresh
        "react-refresh/only-export-components": "warn",
        // A11y
        // (optional additions depending on your team’s commitment to accessibility)
        // Import rules
        "import/extensions": [
            "error",
            "ignorePackages",
            {
                js: "never",
                jsx: "never",
                ts: "never",
                tsx: "never",
            },
        ],
        "import/order": [
            "error",
            {
                groups: ["builtin", "external", "internal", "parent", "sibling", "index"],
                pathGroups: [
                    {
                        pattern: "react",
                        group: "external",
                        position: "before",
                    },
                ],
                pathGroupsExcludedImportTypes: ["react"],
                "newlines-between": "always",
                alphabetize: {
                    order: "asc",
                    caseInsensitive: true,
                },
            },
        ],
        "import/prefer-default-export": "off",
        "import/no-cycle": "off",
        "import/no-named-as-default": "off",
        "import/no-named-as-default-member": "off",
    },
});
exports.default = {
    meta: {
        name: "@launchware/eslint-config-react",
        version: "0.1.1",
    },
    configs: {
        recommended: flatConfig,
    },
};
//# sourceMappingURL=eslint-config-react.js.map
